<?php

use CRM_Activitystatus_ExtensionUtil as E;

class CRM_Activitystatus_Utils {

  /**
   *
   */
  public static function getDefaultActivityStatus() {
    $option_group_id = \Civi\Api4\OptionGroup::get()
      ->addSelect('id')
      ->addWhere('name', '=', 'activity_status')
      ->setCheckPermissions(false)
      ->execute()[0]['id'];

    $oval = \Civi\Api4\OptionValue::get(FALSE)
      ->addSelect('value')
      ->addWhere('option_group_id', '=', $option_group_id)
      ->addWhere('is_default', '=', true)
      ->execute()
      ->first();

    return $oval['value'] ?? NULL;
  }

  /**
   *
   */
  public static function getDefaultActivityPriority() {
    $option_group_id = \Civi\Api4\OptionGroup::get(FALSE)
      ->addSelect('id')
      ->addWhere('name', '=', 'priority')
      ->execute()[0]['id'];

    $oval = \Civi\Api4\OptionValue::get(FALSE)
      ->addSelect('value')
      ->addWhere('option_group_id', '=', $option_group_id)
      ->addWhere('is_default', '=', true)
      ->setCheckPermissions(false)
      ->execute()
      ->first();

    return $oval['value'] ?? NULL;
  }

  /**
   * When the settings form is updated, set the new activity status in the
   * option value table.
   *
   * @param $old_value
   * @param $new_value
   */
  public static function onChangeDefaultActivityStatus($old_value, $new_value) {
    $option_group_id = \Civi\Api4\OptionGroup::get()
      ->addSelect('id')
      ->addWhere('name', '=', 'activity_status')
      ->setCheckPermissions(false)
      ->execute()[0]['id'];

    CRM_Core_DAO::executeQuery('UPDATE civicrm_option_value SET is_default = NULL WHERE option_group_id = %1 AND is_default = 1', [
      1 => [$option_group_id, 'Positive'],
    ]);
    CRM_Core_DAO::executeQuery('UPDATE civicrm_option_value SET is_default = 1 WHERE option_group_id = %1 AND value = %2', [
      1 => [$option_group_id, 'Positive'],
      2 => [$new_value, 'Positive'],
    ]);

    CRM_Core_Session::setStatus(E::ts('The default Activity Status has been updated.'), '', 'success');
  }

  /**
   * When the settings form is updated, set the new default priority in the
   * option value table.
   *
   * @param $old_value
   * @param $new_value
   */
  public static function onChangeDefaultActivityPriority($old_value, $new_value) {
    $option_group_id = \Civi\Api4\OptionGroup::get(FALSE)
      ->addSelect('id')
      ->addWhere('name', '=', 'priority')
      ->execute()[0]['id'];

    CRM_Core_DAO::executeQuery('UPDATE civicrm_option_value SET is_default = NULL WHERE option_group_id = %1 AND is_default = 1', [
      1 => [$option_group_id, 'Positive'],
    ]);
    CRM_Core_DAO::executeQuery('UPDATE civicrm_option_value SET is_default = 1 WHERE option_group_id = %1 AND value = %2', [
      1 => [$option_group_id, 'Positive'],
      2 => [$new_value, 'Positive'],
    ]);

    CRM_Core_Session::setStatus(E::ts('The default Activity Priority has been updated.'), '', 'success');
  }

}
